feast.storage package — Feast 0.3.2 documentation

# feast.storage package

## Submodules

## feast.storage.Redis_pb2 module

class `feast.storage.Redis_pb2.` `RedisKey`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `entities`

    Field feast.storage.RedisKey.entities

  `feature_set`

    Field feast.storage.RedisKey.feature_set

## Module contents